// src/index.ts
import * as crypto from "crypto";
import enhancedResolve from "enhanced-resolve";
import * as esbuild from "esbuild";
import * as fs2 from "fs";
import * as path2 from "path";
import * as tsconfck from "tsconfck";

// src/sourceMaps.ts
import remapping from "@ampproject/remapping";
import * as convertSourceMap from "convert-source-map";
import * as fs from "fs";
import * as path from "path";
var nullSourceMap = {
  names: [],
  sources: [],
  mappings: "",
  version: 3
};
function combineSourcemaps(filename, sourcemapList) {
  if (sourcemapList.length === 0 || sourcemapList.every((m) => m.sources.length === 0)) {
    return { ...nullSourceMap };
  }
  let map;
  let mapIndex = 1;
  const useArrayInterface = sourcemapList.slice(0, -1).find((m) => m.sources.length !== 1) === void 0;
  if (useArrayInterface) {
    map = remapping(sourcemapList, () => null);
  } else {
    map = remapping(sourcemapList[0], function loader(sourcefile) {
      if (sourcefile === filename && sourcemapList[mapIndex]) {
        return sourcemapList[mapIndex++];
      } else {
        return { ...nullSourceMap };
      }
    });
  }
  if (!map.file) {
    delete map.file;
  }
  return map;
}
function appendInlineSourceMap(code, map) {
  return code + "\n//# sourceMappingURL=" + mapToDataUrl(map);
}
function mapToDataUrl(map) {
  return "data:application/json;charset=utf-8;base64," + Buffer.from(JSON.stringify(map)).toString("base64");
}
function loadSourceMap(code, file) {
  let converter = convertSourceMap.fromSource(code);
  try {
    converter ||= convertSourceMap.fromMapFileSource(
      code,
      (ref) => fs.readFileSync(path.resolve(file, "..", ref), "utf8")
    );
  } catch {
  }
  return converter?.toObject();
}

// src/index.ts
var kBuildExtensions = Symbol.for("esbuild-extra:extensions");
function wrapPlugins(options) {
  return {
    ...options,
    plugins: options.plugins?.map((plugin) => ({
      name: plugin.name,
      setup(build2) {
        Object.assign(build2, getBuildExtensions(build2, plugin.name));
        return plugin.setup(build2);
      }
    }))
  };
}
function getBuildExtensions(pluginBuild, pluginName) {
  if ("onTransform" in pluginBuild) {
    return pluginBuild;
  }
  const { initialOptions } = pluginBuild;
  let extensions = Reflect.get(initialOptions, kBuildExtensions);
  if (!extensions) {
    const onLoadRules = [];
    const onTransformRules = [];
    const onResolveRulesMap = /* @__PURE__ */ new Map();
    const onResolvedRules = [];
    let globalWatchFiles;
    let globalWatchDirs;
    if (initialOptions.metafile) {
      pluginBuild.onStart(() => {
        globalWatchFiles = [];
        globalWatchDirs = [];
      });
      pluginBuild.onEnd((result) => {
        const metafile = result.metafile;
        metafile.watchFiles = Array.from(new Set(globalWatchFiles));
        metafile.watchDirs = Array.from(new Set(globalWatchDirs));
      });
    }
    const loaders = {
      ".js": "js",
      ".jsx": "jsx",
      ".ts": "ts",
      ".tsx": "tsx",
      ".mjs": "js",
      ".cjs": "js",
      ".mts": "ts",
      ".cts": "ts",
      ...initialOptions.loader
    };
    const getLoader = (id) => {
      return loaders[path2.extname(id)];
    };
    const extsByLoader = Object.entries(loaders).reduce(
      (acc, [ext, loader]) => {
        acc[loader] ||= [];
        acc[loader].push(ext);
        return acc;
      },
      {}
    );
    async function load(partialArgs) {
      const args = {
        namespace: "file",
        pluginData: void 0,
        suffix: "",
        ...partialArgs
      };
      let result = null;
      let errors = [];
      for (const [pluginName2, options, callback] of onLoadRules) {
        if (args.namespace !== (options.namespace ?? "file")) {
          continue;
        }
        if (!options.filter.test(args.path)) {
          continue;
        }
        try {
          result = await callback(args);
          if (result) {
            break;
          }
        } catch (error) {
          errors.push({
            id: "load-error",
            pluginName: pluginName2,
            text: error.message,
            location: null,
            notes: [],
            detail: error
          });
        }
      }
      if (!result) {
        try {
          result = {
            contents: fs2.readFileSync(args.path),
            loader: getLoader(args.path)
          };
        } catch {
        }
      }
      return {
        ...result,
        errors
      };
    }
    async function transform2(args) {
      const loadResult = args.isResult ? omitKeys(args, ["isResult", "path", "suffix", "namespace"]) : await load(args);
      if (!loadResult.contents) {
        if (loadResult.watchFiles) {
          globalWatchFiles?.push(...loadResult.watchFiles);
        }
        if (loadResult.watchDirs) {
          globalWatchDirs?.push(...loadResult.watchDirs);
        }
        return loadResult;
      }
      const {
        errors = [],
        warnings = [],
        watchFiles = [],
        watchDirs = []
      } = args;
      let initialCode;
      let loader;
      let transformArgs;
      let jsTransforms;
      let jsxTransforms;
      let resolveDir = loadResult.resolveDir ?? args.resolveDir;
      let maps = [];
      const isNamespaceCompatible = ({
        namespace = "*"
      }) => {
        if (namespace === "*") {
          return true;
        }
        if ((args.namespace ?? "file") === namespace) {
          return true;
        }
        return false;
      };
      const applyTransformRule = async (rule, rules) => {
        const [pluginName2, options, callback] = rule;
        if (!isNamespaceCompatible(options)) {
          return;
        }
        const filePath = transformArgs?.path ?? args.path;
        loader ||= getLoader(filePath) || "file";
        const filter = options.filter;
        if (!filter.test(filePath)) {
          if (loader == "ts" || loader == "jsx") {
            if (filter.test(filePath + ".js")) {
              jsTransforms ||= /* @__PURE__ */ new Set();
              jsTransforms.add(rule);
            }
          } else if (loader == "tsx") {
            if (filter.test(filePath + ".jsx")) {
              jsxTransforms ||= /* @__PURE__ */ new Set();
              jsxTransforms.add(rule);
            } else if (filter.test(filePath + ".js")) {
              jsTransforms ||= /* @__PURE__ */ new Set();
              jsTransforms.add(rule);
            }
          }
          return;
        }
        if (loader == "js" && jsTransforms && rules != jsTransforms) {
          if (!jsxTransforms || !jsxTransforms.has(rule)) {
            jsTransforms.add(rule);
          }
          return;
        }
        if (loader == "jsx" && jsxTransforms && !rules) {
          jsxTransforms.add(rule);
          return;
        }
        transformArgs ||= {
          path: args.path,
          code: initialCode = decodeContents(loadResult.contents),
          loader,
          namespace: args.namespace ?? "file",
          pluginData: loadResult.pluginData || args.pluginData || {},
          suffix: args.suffix || ""
        };
        try {
          const result = await callback(transformArgs);
          if (result) {
            if (result.code) {
              transformArgs.code = result.code;
            }
            if (result.loader && result.loader != transformArgs.loader) {
              loader = transformArgs.loader = result.loader;
              const exts = extsByLoader[loader];
              if (exts) {
                transformArgs.initialPath = args.path;
                transformArgs.path = args.path + exts[0];
              }
            }
            if (result.warnings) {
              warnings.push(...result.warnings);
            }
            if (result.errors) {
              errors.push(...result.errors);
            }
            if (result.map) {
              maps.push(result.map);
            }
            if (result.watchFiles) {
              watchFiles.push(...result.watchFiles);
            }
            if (result.watchDirs) {
              watchDirs.push(...result.watchDirs);
            }
            if (result.resolveDir) {
              resolveDir = result.resolveDir;
            }
            if (result.pluginData) {
              transformArgs.pluginData ||= {};
              Object.assign(transformArgs.pluginData, result.pluginData);
            }
          }
        } catch (error) {
          return {
            id: "transform-error",
            pluginName: pluginName2,
            text: error.message,
            location: error.location || null,
            notes: [],
            detail: error
          };
        }
      };
      transform: {
        for (const rule of onTransformRules) {
          const error = await applyTransformRule(rule);
          if (error) {
            errors.push(error);
            break transform;
          }
        }
        if (jsTransforms || jsxTransforms) {
          let tsconfigPath;
          let tsconfigRaw;
          if (/\.[mc]?tsx?$/.test(args.path)) {
            try {
              tsconfigPath = await tsconfck.find(args.path, {
                root: process.cwd()
              });
              tsconfigRaw = fs2.readFileSync(tsconfigPath, "utf8");
            } catch {
            }
          }
          const createEsbuildRule = (options) => [
            "esbuild-extra:transform",
            { filter: /.*/ },
            async (args2) => {
              const result = await esbuild.transform(args2.code, {
                format: "esm",
                sourcemap: true,
                platform: "neutral",
                sourcefile: args2.path,
                loader: args2.loader,
                tsconfigRaw,
                ...options
              });
              return {
                code: result.code,
                map: JSON.parse(result.map),
                loader: args2.loader == "tsx" ? "jsx" : "js",
                warnings: result.warnings
              };
            }
          ];
          if (jsxTransforms) {
            const error = await applyTransformRule(
              createEsbuildRule({ jsx: "preserve" }),
              jsxTransforms
            );
            if (error) {
              errors.push(error);
              break transform;
            }
            for (const rule of jsxTransforms) {
              const error2 = await applyTransformRule(rule, jsxTransforms);
              if (error2) {
                errors.push(error2);
                break transform;
              }
            }
          }
          if (jsTransforms) {
            const error = await applyTransformRule(
              createEsbuildRule({
                // This ensures the tsconfig.json is respected in cases
                // where a TypeScript file has had ".jsx" appended to
                // its transformArgs path.
                sourcefile: args.path,
                loader: getLoader(args.path)
              }),
              jsTransforms
            );
            if (error) {
              errors.push(error);
              break transform;
            }
            for (const rule of jsTransforms) {
              const error2 = await applyTransformRule(rule, jsTransforms);
              if (error2) {
                errors.push(error2);
                break transform;
              }
            }
          }
        }
      }
      if (watchFiles.length) {
        globalWatchFiles?.push(...watchFiles);
      }
      if (watchDirs.length) {
        globalWatchDirs?.push(...watchDirs);
      }
      if (!transformArgs || transformArgs.code === initialCode) {
        return {
          ...loadResult,
          pluginData: transformArgs?.pluginData || loadResult.pluginData,
          resolveDir,
          watchFiles,
          watchDirs,
          warnings,
          errors
        };
      }
      const inputSourcemap = loadSourceMap(initialCode, args.path);
      if (inputSourcemap) {
        maps.unshift(inputSourcemap);
      }
      const transformedCode = transformArgs.code;
      const combinedMap = maps.length > 1 ? combineSourcemaps(args.path, [...maps].reverse()) : maps[0];
      if (combinedMap) {
        const pathToSourceRoot = sourceRoot || path2.dirname(args.path);
        const pathToWorkingDir = path2.relative(pathToSourceRoot, absWorkingDir);
        combinedMap.sources = combinedMap.sources.map((source) => {
          let src = path2.relative(pathToSourceRoot, source);
          if (!src.startsWith("..")) {
            return src;
          }
          src = path2.relative(absWorkingDir, source);
          if (src.startsWith("..")) {
            return source;
          }
          return path2.join(pathToWorkingDir, src);
        });
        if (sourceRoot) {
          combinedMap.sourceRoot = sourceRoot;
        }
      }
      return {
        contents: combinedMap ? appendInlineSourceMap(transformedCode, combinedMap) : transformedCode,
        loader: transformArgs.loader,
        pluginData: transformArgs.pluginData,
        resolveDir,
        watchFiles,
        watchDirs,
        warnings,
        errors
      };
    }
    const chunks = /* @__PURE__ */ new Map();
    const files = /* @__PURE__ */ new Map();
    const isEmittedPath = (id) => {
      for (const chunk of chunks.values()) {
        if (chunk.id === id) {
          return true;
        }
      }
      for (const file of files.values()) {
        if (file.id === id) {
          return true;
        }
      }
      return false;
    };
    const emitChunk = async (chunkOptions) => {
      const format = chunkOptions.format || initialOptions.format;
      const config = {
        ...initialOptions,
        format,
        outdir: chunkOptions.outdir ? path2.resolve(outdir || absWorkingDir, chunkOptions.outdir) : outdir,
        bundle: chunkOptions.bundle ?? initialOptions.bundle,
        splitting: format === "esm" ? chunkOptions.splitting ?? initialOptions.splitting : false,
        platform: chunkOptions.platform ?? initialOptions.platform,
        target: chunkOptions.target ?? initialOptions.target,
        plugins: chunkOptions.plugins ?? initialOptions.plugins,
        external: chunkOptions.external ?? initialOptions.external,
        jsxFactory: "jsxFactory" in chunkOptions ? chunkOptions.jsxFactory : initialOptions.jsxFactory,
        entryNames: initialOptions.chunkNames || initialOptions.entryNames,
        write: chunkOptions.write ?? initialOptions.write ?? true,
        globalName: void 0,
        outfile: void 0,
        metafile: true
      };
      Object.defineProperty(config, "chunk", {
        enumerable: false,
        value: true
      });
      if (chunkOptions.contents) {
        delete config.entryPoints;
        config.stdin = {
          sourcefile: chunkOptions.path,
          contents: chunkOptions.contents.toString(),
          resolveDir: sourceRoot || absWorkingDir
        };
      } else {
        config.entryPoints = [chunkOptions.path];
      }
      if (config.define) {
        delete config.define["this"];
      }
      const result = await esbuild.build(config);
      const outputs = result.metafile.outputs;
      const outFile = Object.entries(outputs).filter(([output]) => !output.endsWith(".map")).find(([output]) => outputs[output].entryPoint);
      if (!outFile) {
        throw new Error("Unable to locate build artifacts");
      }
      const resolvedOutputFile = path2.resolve(outFile[0]);
      const buffer = result.outputFiles ? result.outputFiles[0].contents : fs2.readFileSync(resolvedOutputFile);
      const chunkResult = {
        ...result,
        id: hash(buffer),
        path: path2.relative(outdir || absWorkingDir, resolvedOutputFile),
        filePath: resolvedOutputFile
      };
      chunks.set(chunkOptions.path, chunkResult);
      return chunkResult;
    };
    const resolveEmittedFile = (pattern, filePath, buffer) => {
      outbase ||= getOutBase(absWorkingDir, initialOptions);
      const dir = path2.relative(outbase, path2.dirname(filePath));
      const name = path2.basename(filePath);
      return path2.resolve(
        outdir || sourceRoot || absWorkingDir,
        computeName(pattern, dir, name, buffer)
      );
    };
    const emitFile = async (source, buffer) => {
      let watchFiles;
      let watchDirs;
      if (!buffer) {
        const result2 = await load({
          pluginData: null,
          namespace: "file",
          suffix: "",
          path: source
        });
        if (result2.contents) {
          buffer = Buffer.from(result2.contents);
        } else {
          buffer = fs2.readFileSync(source);
        }
        if (result2.watchFiles) {
          watchFiles = result2.watchFiles;
        }
        if (result2.watchDirs) {
          watchDirs = result2.watchDirs;
        }
      } else if (typeof buffer === "string") {
        buffer = Buffer.from(buffer);
      }
      const outputFile = resolveEmittedFile(assetNames, source, buffer);
      const bytes = buffer.length;
      const write = initialOptions.write ?? true;
      if (write) {
        fs2.mkdirSync(path2.dirname(outputFile), {
          recursive: true
        });
        fs2.writeFileSync(outputFile, buffer);
      }
      const outputFiles = !write ? [createOutputFile(outputFile, Buffer.from(buffer))] : void 0;
      const result = createResult(outputFiles, {
        inputs: {
          [path2.relative(absWorkingDir, source)]: {
            bytes,
            imports: []
          }
        },
        outputs: {
          [path2.relative(absWorkingDir, outputFile)]: {
            bytes,
            inputs: {
              [path2.relative(absWorkingDir, source)]: {
                bytesInOutput: bytes
              }
            },
            imports: [],
            exports: [],
            entryPoint: path2.relative(absWorkingDir, source)
          }
        },
        watchFiles: watchFiles || [],
        watchDirs: watchDirs || []
      });
      const fileResult = {
        ...result,
        id: hash(buffer),
        path: path2.relative(outdir || absWorkingDir, outputFile),
        filePath: outputFile
      };
      files.set(source, fileResult);
      return fileResult;
    };
    const nodeResolve = enhancedResolve.create({
      extensions: initialOptions.resolveExtensions || [
        ".tsx",
        ".ts",
        ".jsx",
        ".js",
        ".css",
        ".json"
      ]
    });
    const postResolve = async (args, resolved) => {
      const { namespace = "file" } = resolved;
      for (const rule of onResolvedRules) {
        const options = rule[1];
        if (!options.filter.test(resolved.path)) {
          continue;
        }
        if (namespace !== (options.namespace ?? "file")) {
          continue;
        }
        const onResolved = rule[2];
        const result = await onResolved(args, resolved);
        if (result) {
          resolved = {
            ...resolved,
            ...result,
            errors: mergeArrays(resolved.errors, result.errors),
            warnings: mergeArrays(resolved.warnings, result.warnings)
          };
        }
      }
      if (resolved.watchFiles) {
        globalWatchFiles?.push(...resolved.watchFiles);
      }
      if (resolved.watchDirs) {
        globalWatchDirs?.push(...resolved.watchDirs);
      }
      return resolved;
    };
    const resolveFile = async (args) => {
      const resolvedPath = await new Promise((setResult, setError) => {
        nodeResolve(
          args.resolveDir,
          args.path,
          (error, result) => error ? setError(error) : setResult(result)
        );
      });
      return postResolve(args, {
        path: resolvedPath,
        pluginName: "node-resolve"
      });
    };
    let {
      absWorkingDir = process.cwd(),
      outfile,
      outdir = outfile ? path2.dirname(outfile) : void 0,
      outbase,
      sourceRoot,
      assetNames = "[dir]/[name]"
    } = initialOptions;
    if (outdir) {
      outdir = path2.resolve(absWorkingDir, outdir);
    }
    if (sourceRoot) {
      sourceRoot = path2.resolve(absWorkingDir, sourceRoot);
    }
    const RESOLVED_AS_FILE = 1;
    const RESOLVED_AS_MODULE = 2;
    extensions = (pluginBuild2, pluginName2) => {
      const onResolve = pluginBuild2.onResolve.bind(pluginBuild2);
      const onLoad = pluginBuild2.onLoad.bind(pluginBuild2);
      return {
        RESOLVED_AS_FILE,
        RESOLVED_AS_MODULE,
        getLoader,
        isEmittedPath,
        emitChunk,
        emitFile,
        async resolveLocallyFirst(path3, options = {}) {
          const isLocalSpecifier = path3.startsWith("./") || path3.startsWith("../");
          if (!isLocalSpecifier) {
            const result2 = await pluginBuild2.resolve(`./${path3}`, options);
            if (result2.path) {
              return {
                ...result2,
                pluginData: RESOLVED_AS_FILE
              };
            }
          }
          const result = await pluginBuild2.resolve(path3, options);
          if (result.path) {
            return {
              ...result,
              pluginData: isLocalSpecifier ? RESOLVED_AS_FILE : RESOLVED_AS_MODULE
            };
          }
          return result;
        },
        onResolve(options, callback) {
          const namespace = options.namespace ?? "file";
          let onResolveRules = onResolveRulesMap.get(namespace) || [];
          if (!onResolveRules.length) {
            onResolveRulesMap.set(namespace, onResolveRules);
          }
          const index = onResolveRules.push([pluginName2, options, callback]);
          onResolve(options, async (args) => {
            const result = await callback(args);
            if (result && result.path) {
              result.pluginName ||= pluginName2;
              return postResolve(args, result);
            }
            if (index < onResolveRules.length) {
              return null;
            }
            if (namespace === "file") {
              return resolveFile(args);
            }
            return null;
          });
        },
        onResolved(options, callback) {
          onResolvedRules.push([pluginName2, options, callback]);
          const namespace = options.namespace ?? "file";
          const onResolveRules = onResolveRulesMap.get(namespace) || [];
          if (!onResolveRules.length) {
            onResolveRulesMap.set(namespace, onResolveRules);
            const index = onResolveRules.push([pluginName2, options, null]);
            onResolve(options, (args) => {
              if (index < onResolveRules.length) {
                return null;
              }
              return resolveFile(args);
            });
          }
        },
        async load(args) {
          const result = await load(args);
          return transform2({
            ...result,
            path: args.path,
            suffix: args.suffix,
            namespace: args.namespace,
            isResult: true
          });
        },
        onLoad(options, callback) {
          onLoad(options, (args) => this.load(args));
          onLoadRules.push([pluginName2, options, callback]);
        },
        onTransform({ loaders: loaders2, extensions: extensions2, ...options }, callback) {
          const patterns = [];
          if (options.filter) {
            patterns.push(options.filter.source);
          }
          if (extensions2) {
            patterns.push(joinRegexSources(extensions2) + "$");
          }
          const loadPatterns = [];
          if (loaders2) {
            let js = false, jsx = false, ts = false, tsx = false;
            const extensions3 = [];
            for (const loader of loaders2) {
              extensions3.push(...extsByLoader[loader]);
              if (loader === "js")
                js = true;
              else if (loader === "jsx")
                jsx = true;
              else if (loader === "ts")
                ts = true;
              else if (loader === "tsx")
                tsx = true;
            }
            patterns.push(
              `\\.${joinRegexSources(
                extensions3.map((ext) => ext.replace(".", ""))
              )}$`
            );
            const loadExtensions = [];
            if (js || jsx) {
              if (!jsx) {
                loadExtensions.push(...extsByLoader.jsx);
              }
              if (!tsx) {
                loadExtensions.push(...extsByLoader.tsx);
              }
              if (!ts && js) {
                loadExtensions.push(...extsByLoader.ts);
              }
            }
            if (loadExtensions.length) {
              loadPatterns.push(
                `\\.${joinRegexSources(
                  [...extensions3, ...loadExtensions].map(
                    (ext) => ext.replace(".", "")
                  )
                )}$`
              );
            }
          }
          if (patterns.length) {
            options.filter = new RegExp(joinRegexSources(patterns));
            onTransformRules.push([pluginName2, options, callback]);
            if (loadPatterns.length) {
              const filter = new RegExp(joinRegexSources(loadPatterns));
              onLoad({ ...options, filter }, (args) => transform2(args));
            } else {
              onLoad(options, (args) => transform2(args));
            }
          }
        }
      };
    };
    Reflect.set(initialOptions, kBuildExtensions, extensions);
  }
  return extensions(pluginBuild, pluginName);
}
function joinRegexSources(sources) {
  return sources.length > 1 ? `(${sources.join("|")})` : sources[0];
}
function decodeContents(contents) {
  if (typeof contents == "string") {
    return contents;
  }
  const decoder = new TextDecoder("utf8");
  return decoder.decode(contents);
}
function hash(buffer) {
  const hash2 = crypto.createHash("sha1");
  hash2.update(Buffer.isBuffer(buffer) ? buffer : Buffer.from(buffer));
  return hash2.digest("hex").substring(0, 8);
}
function computeName(pattern, dir, name, buffer) {
  return `${pattern.replace("[name]", () => path2.basename(name, path2.extname(name))).replace("[ext]", () => path2.extname(name)).replace(/(\/)?\[dir\](\/)?/, (_, leadingSlash, trailingSlash) => {
    if (dir) {
      return `${leadingSlash || ""}${dir}${trailingSlash || ""}`;
    }
    if (!leadingSlash && trailingSlash) {
      return "";
    }
    return leadingSlash || "";
  }).replace("[dir]", dir).replace("[hash]", () => hash(buffer))}${path2.extname(name)}`;
}
function getOutBase(absWorkingDir, options) {
  if (options.outbase) {
    return options.outbase;
  }
  const entryPoints = options.entryPoints || [];
  if (!entryPoints.length) {
    return absWorkingDir;
  }
  const separator = /\/+|\\+/;
  return (Array.isArray(entryPoints) ? entryPoints.map((entry) => typeof entry == "string" ? entry : entry.out) : Object.values(entryPoints)).map(
    (entry) => path2.dirname(path2.resolve(absWorkingDir, entry)).split(separator)
  ).reduce((result, chunk) => {
    const len = Math.min(chunk.length, result.length);
    for (let i = 0; i < len; i++) {
      if (chunk[i] !== result[i]) {
        return result.splice(0, i);
      }
    }
    return result.splice(0, len);
  }).join(path2.sep) || path2.sep;
}
function createOutputFile(path3, contents) {
  return {
    path: path3,
    contents,
    get text() {
      return contents.toString();
    }
  };
}
function createResult(outputFiles, metafile) {
  return {
    errors: [],
    warnings: [],
    outputFiles,
    metafile,
    mangleCache: void 0
  };
}
function omitKeys(obj, props) {
  const result = {};
  for (const prop of Object.keys(obj)) {
    if (!props.includes(prop)) {
      result[prop] = obj[prop];
    }
  }
  return result;
}
function mergeArrays(a, b) {
  if (!a)
    return b;
  if (!b)
    return a;
  return [...a, ...b];
}
export {
  getBuildExtensions,
  wrapPlugins
};
